% phonenumbers package: phonenumbers-UK.def
% Module for British telephone numbers
% Author: K. Wehr
% Version: 2.6
% Date: 2025-05-06
\clist_const:Nn \c_phone_UK_ortsvorwahlen_clist {0113,
0114,
0115,
0116,
0117,
0118,
01200,
01202,
01204,
01205,
01206,
01207,
01208,
01209,
0121,
01223,
01224,
01225,
01226,
01227,
01228,
01229,
01233,
01234,
01235,
01236,
01237,
01239,
01241,
01242,
01243,
01244,
01245,
01246,
01248,
01249,
01250,
01252,
01253,
01254,
01255,
01256,
01257,
01258,
01259,
01260,
01261,
01262,
01263,
01264,
01267,
01268,
01269,
01270,
01271,
01273,
01274,
01275,
01276,
01277,
01278,
01279,
01280,
01282,
01283,
01284,
01285,
01286,
01287,
01288,
01289,
01290,
01291,
01292,
01293,
01294,
01295,
01296,
01297,
01298,
01299,
01300,
01301,
01302,
01303,
01304,
01305,
01306,
01307,
01308,
01309,
0131,
01320,
01322,
01323,
01324,
01325,
01326,
01327,
01328,
01329,
01330,
01332,
01333,
01334,
01335,
01337,
01339,
01340,
01341,
01342,
01343,
01344,
01346,
01347,
01348,
01349,
01350,
01352,
01353,
01354,
01355,
01356,
01357,
01358,
01359,
01360,
01361,
01362,
01363,
01364,
01366,
01367,
01368,
01369,
01371,
01372,
01373,
01375,
01376,
01377,
01379,
01380,
01381,
01382,
01383,
01384,
01386,
01387,
013873,
01388,
01389,
01392,
01394,
01395,
01397,
01398,
01400,
01403,
01404,
01405,
01406,
01407,
01408,
01409,
0141,
01420,
01422,
01423,
01424,
01425,
01427,
01428,
01429,
01430,
01431,
01432,
01433,
01434,
01435,
01436,
01437,
01438,
01439,
01440,
01442,
01443,
01444,
01445,
01446,
01449,
01450,
01451,
01452,
01453,
01454,
01455,
01456,
01457,
01458,
01460,
01461,
01462,
01463,
01464,
01465,
01466,
01467,
01469,
01470,
01471,
01472,
01473,
01474,
01475,
01476,
01477,
01478,
01479,
01480,
01481,
01482,
01483,
01484,
01485,
01487,
01488,
01489,
01490,
01491,
01492,
01493,
01494,
01495,
01496,
01497,
01499,
01501,
01502,
01503,
01505,
01506,
01507,
01508,
01509,
0151,
01520,
01522,
01524,
015242,
01525,
01526,
01527,
01528,
01529,
01530,
01531,
01534,
01535,
01536,
01538,
01539,
015394,
015395,
015396,
01540,
01542,
01543,
01544,
01545,
01546,
01547,
01548,
01549,
01550,
01553,
01554,
01555,
01556,
01557,
01558,
01559,
01560,
01561,
01562,
01563,
01564,
01565,
01566,
01567,
01568,
01569,
01570,
01571,
01572,
01573,
01575,
01576,
01577,
01578,
01579,
01580,
01581,
01582,
01583,
01584,
01586,
01588,
01590,
01591,
01592,
01593,
01594,
01595,
01597,
01598,
01599,
01600,
01603,
01604,
01606,
01608,
01609,
0161,
01620,
01621,
01622,
01623,
01624,
01625,
01626,
01628,
01629,
01630,
01631,
01633,
01634,
01635,
01636,
01637,
01638,
01639,
01641,
01642,
01643,
01644,
01646,
01647,
01650,
01651,
01652,
01653,
01654,
01655,
01656,
01659,
01661,
01663,
01664,
01665,
01666,
01667,
01668,
01669,
01670,
01671,
01672,
01673,
01674,
01675,
01676,
01677,
01678,
01680,
01681,
01683,
01684,
01685,
01686,
01687,
01688,
01689,
01690,
01691,
01692,
01694,
01695,
01697,
016973,
016974,
016977,
01698,
01700,
01702,
01704,
01706,
01707,
01708,
01709,
01720,
01721,
01722,
01723,
01724,
01725,
01726,
01727,
01728,
01729,
01730,
01732,
01733,
01736,
01737,
01738,
01740,
01743,
01744,
01745,
01746,
01747,
01748,
01749,
01750,
01751,
01752,
01753,
01754,
01756,
01757,
01758,
01759,
01760,
01761,
01763,
01764,
01765,
01766,
01767,
01768,
017683,
017684,
017687,
01769,
01770,
01771,
01772,
01773,
01775,
01776,
01777,
01778,
01779,
01780,
01782,
01784,
01785,
01786,
01787,
01788,
01789,
01790,
01792,
01793,
01794,
01795,
01796,
01797,
01798,
01799,
01803,
01805,
01806,
01807,
01808,
01809,
01821,
01822,
01823,
01824,
01825,
01827,
01828,
01829,
01830,
01832,
01833,
01834,
01835,
01837,
01838,
01840,
01841,
01842,
01843,
01844,
01845,
01847,
01848,
01851,
01852,
01854,
01855,
01856,
01857,
01858,
01859,
01862,
01863,
01864,
01865,
01866,
01869,
01870,
01871,
01872,
01873,
01874,
01875,
01876,
01877,
01878,
01879,
01880,
01882,
01883,
01884,
01885,
01886,
01887,
01888,
01889,
01890,
01892,
01895,
01896,
01899,
01900,
01902,
01903,
01904,
01905,
01908,
01909,
0191,
01920,
01922,
01923,
01924,
01925,
01926,
01928,
01929,
01931,
01932,
01933,
01934,
01935,
01937,
01938,
01939,
01942,
01943,
01944,
01945,
01946,
019467,
01947,
01948,
01949,
01950,
01951,
01952,
01953,
01954,
01955,
01957,
01959,
01962,
01963,
01964,
01967,
01968,
01969,
01970,
01971,
01972,
01974,
01975,
01977,
01978,
01980,
01981,
01982,
01983,
01984,
01985,
01986,
01987,
01988,
01989,
01992,
01993,
01994,
01995,
01997,
020,
023,
024,
028,
029}
\clist_const:Nn \c_phone_UK_obligatorische_ortsvorwahlen_clist {01202,
01224,
01273,
01274,
01642,
01908}
\clist_const:Nn \c_phone_UK_sondervorwahlen_clist {0300,
0303,
0306,
0330,
0331,
0333,
0343,
0344,
0345,
0370,
0371,
0372,
05511,
05516,
05555,
05588,
05600,
05601,
05602,
05603,
05604,
07000,
07002,
07003,
07004,
07005,
07006,
07008,
07009,
07010,
07011,
07012,
07013,
07014,
07015,
07016,
07017,
07018,
07019,
07021,
07022,
07023,
07024,
07026,
07027,
07028,
07029,
07030,
07031,
07032,
07033,
07034,
07035,
07036,
07037,
07038,
07039,
07040,
07041,
07042,
07043,
07044,
07045,
07046,
07047,
07048,
07049,
07052,
07053,
07054,
07055,
07056,
07057,
07058,
07059,
07060,
07061,
07062,
07063,
07064,
07065,
07066,
07067,
07068,
07069,
07070,
07071,
07072,
07073,
07074,
07076,
07077,
07078,
07079,
07080,
07081,
07082,
07083,
07084,
07085,
07086,
07087,
07088,
07089,
07090,
07091,
07093,
07094,
07096,
07098,
07099,
07106,
07107,
07300,
07301,
07302,
07303,
07304,
07305,
07306,
07307,
07308,
07309,
07310,
07311,
07312,
07340,
07341,
07342,
07354,
07355,
07356,
07357,
07358,
07359,
07360,
07361,
07362,
07363,
07364,
07365,
07366,
07367,
07368,
07369,
07375,
07376,
07377,
07378,
07379,
07380,
07381,
07382,
07383,
07384,
07385,
07386,
07387,
07388,
07389,
07390,
07391,
07392,
07393,
07394,
07395,
07396,
07397,
07398,
07399,
07400,
07401,
07402,
07403,
07404,
07405,
07406,
07407,
07408,
07409,
07410,
07411,
07412,
07413,
07414,
07415,
07416,
07417,
07418,
07419,
07420,
07421,
07422,
07423,
07424,
07425,
07426,
07427,
07428,
07429,
07430,
07431,
07432,
07433,
07434,
07435,
07436,
07437,
07438,
07440,
07441,
07442,
07443,
07444,
07445,
07446,
07447,
07448,
07449,
07450,
07451,
07452,
07453,
07454,
07455,
07456,
07457,
07458,
07459,
07460,
07461,
07462,
07463,
07464,
07465,
07466,
07467,
07468,
07469,
07470,
07471,
07472,
07473,
07474,
07475,
07476,
07477,
07478,
07479,
07480,
07481,
07482,
07483,
07484,
07485,
07486,
07487,
07488,
07489,
07490,
07491,
07492,
07493,
07494,
07495,
07496,
07497,
07498,
07499,
07500,
07501,
07502,
07503,
07504,
07505,
07506,
07507,
07508,
07509,
07510,
07511,
07512,
07513,
07514,
07515,
07516,
07517,
07518,
07519,
07520,
07521,
07522,
07523,
07525,
07526,
07527,
07528,
07529,
07530,
07531,
07532,
07533,
07534,
07535,
07536,
07537,
07538,
07539,
07540,
07541,
07542,
07543,
07544,
07545,
07546,
07547,
07548,
07549,
07550,
07551,
07552,
07553,
07554,
07555,
07556,
07557,
07558,
07559,
07560,
07561,
07562,
07563,
07564,
07565,
07566,
07567,
07568,
07569,
07570,
07572,
07573,
07574,
07575,
07576,
07577,
07578,
07579,
07580,
07581,
07582,
07583,
07584,
07585,
07586,
07587,
07588,
07589,
07590,
07591,
07592,
07593,
07594,
07595,
07596,
07597,
07598,
07599,
07600,
07602,
07623,
07624,
07625,
07626,
07640,
07641,
07644,
07654,
07659,
07660,
07661,
07663,
07666,
07669,
07677,
07681,
07693,
07699,
07700,
07701,
07702,
07703,
07704,
07705,
07706,
07707,
07708,
07709,
07710,
07711,
07712,
07713,
07714,
07715,
07716,
07717,
07718,
07719,
07720,
07721,
07722,
07723,
07724,
07725,
07726,
07727,
07728,
07729,
07730,
07731,
07732,
07733,
07734,
07735,
07736,
07737,
07738,
07739,
07740,
07741,
07742,
07743,
07744,
07745,
07746,
07747,
07748,
07749,
07750,
07751,
07752,
07753,
07754,
07755,
07756,
07757,
07758,
07759,
07760,
07761,
07762,
07763,
07764,
07765,
07766,
07767,
07768,
07769,
07770,
07771,
07772,
07773,
07774,
07775,
07776,
07777,
07778,
07779,
07780,
07781,
07782,
07783,
07784,
07785,
07786,
07787,
07788,
07789,
07790,
07791,
07792,
07793,
07794,
07795,
07796,
07797,
07798,
07799,
07800,
07801,
07802,
07803,
07804,
07805,
07806,
07807,
07808,
07809,
07810,
07811,
07812,
07813,
07814,
07815,
07816,
07817,
07818,
07819,
07820,
07821,
07822,
07823,
07824,
07825,
07826,
07827,
07828,
07829,
07830,
07831,
07832,
07833,
07834,
07835,
07836,
07837,
07838,
07839,
07840,
07841,
07842,
07843,
07844,
07845,
07846,
07847,
07848,
07849,
07850,
07851,
07852,
07853,
07854,
07855,
07856,
07857,
07858,
07859,
07860,
07861,
07862,
07863,
07864,
07865,
07866,
07867,
07868,
07869,
07870,
07871,
07872,
07873,
07874,
07875,
07876,
07877,
07878,
07879,
07880,
07881,
07882,
07883,
07884,
07885,
07886,
07887,
07888,
07889,
07890,
07891,
07892,
07893,
07894,
07895,
07896,
07897,
07898,
07899,
07900,
07901,
07902,
07903,
07904,
07905,
07906,
07907,
07908,
07909,
07910,
07911,
07912,
07913,
07914,
07915,
07916,
07917,
07918,
07919,
07920,
07921,
07922,
07923,
07924,
07925,
07926,
07927,
07928,
07929,
07930,
07931,
07932,
07933,
07934,
07935,
07936,
07937,
07938,
07939,
07940,
07941,
07942,
07943,
07944,
07945,
07946,
07947,
07948,
07949,
07950,
07951,
07952,
07953,
07954,
07955,
07956,
07957,
07958,
07959,
07960,
07961,
07962,
07963,
07964,
07965,
07966,
07967,
07968,
07969,
07970,
07971,
07972,
07973,
07974,
07975,
07976,
07977,
07978,
07979,
07980,
07981,
07982,
07983,
07984,
07985,
07986,
07987,
07988,
07989,
07990,
07999,
0800,
0808,
0820,
0843,
0844,
0845,
0870,
0871,
0872,
0897,
0899,
0900,
0901,
0902,
0903,
0904,
0905,
0906,
0907,
0911,
0912,
0913}
\tl_const:cn {c_phone_UK_ortsname_0113_tl} {Leeds}
\tl_const:cn {c_phone_UK_ortsname_0114_tl} {Sheffield}
\tl_const:cn {c_phone_UK_ortsname_0115_tl} {Nottingham}
\tl_const:cn {c_phone_UK_ortsname_0116_tl} {Leicester}
\tl_const:cn {c_phone_UK_ortsname_0117_tl} {Bristol}
\tl_const:cn {c_phone_UK_ortsname_0118_tl} {Reading}
\tl_const:cn {c_phone_UK_ortsname_01200_tl} {Clitheroe}
\tl_const:cn {c_phone_UK_ortsname_01202_tl} {Bournemouth}
\tl_const:cn {c_phone_UK_ortsname_01204_tl} {Bolton}
\tl_const:cn {c_phone_UK_ortsname_01205_tl} {Boston}
\tl_const:cn {c_phone_UK_ortsname_01206_tl} {Colchester}
\tl_const:cn {c_phone_UK_ortsname_01207_tl} {Consett}
\tl_const:cn {c_phone_UK_ortsname_01208_tl} {Bodmin}
\tl_const:cn {c_phone_UK_ortsname_01209_tl} {Redruth}
\tl_const:cn {c_phone_UK_ortsname_0121_tl} {Birmingham}
\tl_const:cn {c_phone_UK_ortsname_01223_tl} {Cambridge}
\tl_const:cn {c_phone_UK_ortsname_01224_tl} {Aberdeen}
\tl_const:cn {c_phone_UK_ortsname_01225_tl} {Bath}
\tl_const:cn {c_phone_UK_ortsname_01226_tl} {Barnsley}
\tl_const:cn {c_phone_UK_ortsname_01227_tl} {Canterbury}
\tl_const:cn {c_phone_UK_ortsname_01228_tl} {Carlisle}
\tl_const:cn {c_phone_UK_ortsname_01229_tl} {Barrow-in-Furness/Millom}
\tl_const:cn {c_phone_UK_ortsname_01233_tl} {Ashford~(Kent)}
\tl_const:cn {c_phone_UK_ortsname_01234_tl} {Bedford}
\tl_const:cn {c_phone_UK_ortsname_01235_tl} {Abingdon}
\tl_const:cn {c_phone_UK_ortsname_01236_tl} {Coatbridge}
\tl_const:cn {c_phone_UK_ortsname_01237_tl} {Bideford}
\tl_const:cn {c_phone_UK_ortsname_01239_tl} {Cardigan}
\tl_const:cn {c_phone_UK_ortsname_01241_tl} {Arbroath}
\tl_const:cn {c_phone_UK_ortsname_01242_tl} {Cheltenham}
\tl_const:cn {c_phone_UK_ortsname_01243_tl} {Chichester}
\tl_const:cn {c_phone_UK_ortsname_01244_tl} {Chester}
\tl_const:cn {c_phone_UK_ortsname_01245_tl} {Chelmsford}
\tl_const:cn {c_phone_UK_ortsname_01246_tl} {Chesterfield}
\tl_const:cn {c_phone_UK_ortsname_01248_tl} {Bangor~(Gwynedd)}
\tl_const:cn {c_phone_UK_ortsname_01249_tl} {Chippenham}
\tl_const:cn {c_phone_UK_ortsname_01250_tl} {Blairgowrie}
\tl_const:cn {c_phone_UK_ortsname_01252_tl} {Aldershot}
\tl_const:cn {c_phone_UK_ortsname_01253_tl} {Blackpool}
\tl_const:cn {c_phone_UK_ortsname_01254_tl} {Blackburn}
\tl_const:cn {c_phone_UK_ortsname_01255_tl} {Clacton-on-Sea}
\tl_const:cn {c_phone_UK_ortsname_01256_tl} {Basingstoke}
\tl_const:cn {c_phone_UK_ortsname_01257_tl} {Coppull}
\tl_const:cn {c_phone_UK_ortsname_01258_tl} {Blandford}
\tl_const:cn {c_phone_UK_ortsname_01259_tl} {Alloa}
\tl_const:cn {c_phone_UK_ortsname_01260_tl} {Congleton}
\tl_const:cn {c_phone_UK_ortsname_01261_tl} {Banff}
\tl_const:cn {c_phone_UK_ortsname_01262_tl} {Bridlington}
\tl_const:cn {c_phone_UK_ortsname_01263_tl} {Cromer}
\tl_const:cn {c_phone_UK_ortsname_01264_tl} {Andover}
\tl_const:cn {c_phone_UK_ortsname_01267_tl} {Carmarthen}
\tl_const:cn {c_phone_UK_ortsname_01268_tl} {Basildon}
\tl_const:cn {c_phone_UK_ortsname_01269_tl} {Ammanford}
\tl_const:cn {c_phone_UK_ortsname_01270_tl} {Crewe}
\tl_const:cn {c_phone_UK_ortsname_01271_tl} {Barnstaple}
\tl_const:cn {c_phone_UK_ortsname_01273_tl} {Brighton}
\tl_const:cn {c_phone_UK_ortsname_01274_tl} {Bradford}
\tl_const:cn {c_phone_UK_ortsname_01275_tl} {Clevedon}
\tl_const:cn {c_phone_UK_ortsname_01276_tl} {Camberley}
\tl_const:cn {c_phone_UK_ortsname_01277_tl} {Brentwood}
\tl_const:cn {c_phone_UK_ortsname_01278_tl} {Bridgwater}
\tl_const:cn {c_phone_UK_ortsname_01279_tl} {Bishops~Stortford}
\tl_const:cn {c_phone_UK_ortsname_01280_tl} {Buckingham}
\tl_const:cn {c_phone_UK_ortsname_01282_tl} {Burnley}
\tl_const:cn {c_phone_UK_ortsname_01283_tl} {Burton-on-Trent}
\tl_const:cn {c_phone_UK_ortsname_01284_tl} {Bury-St-Edmunds}
\tl_const:cn {c_phone_UK_ortsname_01285_tl} {Cirencester}
\tl_const:cn {c_phone_UK_ortsname_01286_tl} {Caernarfon}
\tl_const:cn {c_phone_UK_ortsname_01287_tl} {Guisborough}
\tl_const:cn {c_phone_UK_ortsname_01288_tl} {Bude}
\tl_const:cn {c_phone_UK_ortsname_01289_tl} {Berwick-on-Tweed}
\tl_const:cn {c_phone_UK_ortsname_01290_tl} {Cumnock}
\tl_const:cn {c_phone_UK_ortsname_01291_tl} {Chepstow}
\tl_const:cn {c_phone_UK_ortsname_01292_tl} {Ayr}
\tl_const:cn {c_phone_UK_ortsname_01293_tl} {Crawley}
\tl_const:cn {c_phone_UK_ortsname_01294_tl} {Ardrossan}
\tl_const:cn {c_phone_UK_ortsname_01295_tl} {Banbury}
\tl_const:cn {c_phone_UK_ortsname_01296_tl} {Aylesbury}
\tl_const:cn {c_phone_UK_ortsname_01297_tl} {Axminster}
\tl_const:cn {c_phone_UK_ortsname_01298_tl} {Buxton}
\tl_const:cn {c_phone_UK_ortsname_01299_tl} {Bewdley}
\tl_const:cn {c_phone_UK_ortsname_01300_tl} {Cerne~Abbas}
\tl_const:cn {c_phone_UK_ortsname_01301_tl} {Arrochar}
\tl_const:cn {c_phone_UK_ortsname_01302_tl} {Doncaster}
\tl_const:cn {c_phone_UK_ortsname_01303_tl} {Folkestone}
\tl_const:cn {c_phone_UK_ortsname_01304_tl} {Dover}
\tl_const:cn {c_phone_UK_ortsname_01305_tl} {Dorchester}
\tl_const:cn {c_phone_UK_ortsname_01306_tl} {Dorking}
\tl_const:cn {c_phone_UK_ortsname_01307_tl} {Forfar}
\tl_const:cn {c_phone_UK_ortsname_01308_tl} {Bridport}
\tl_const:cn {c_phone_UK_ortsname_01309_tl} {Forres}
\tl_const:cn {c_phone_UK_ortsname_0131_tl} {Edinburgh}
\tl_const:cn {c_phone_UK_ortsname_01320_tl} {Fort~Augustus}
\tl_const:cn {c_phone_UK_ortsname_01322_tl} {Dartford}
\tl_const:cn {c_phone_UK_ortsname_01323_tl} {Eastbourne}
\tl_const:cn {c_phone_UK_ortsname_01324_tl} {Falkirk}
\tl_const:cn {c_phone_UK_ortsname_01325_tl} {Darlington}
\tl_const:cn {c_phone_UK_ortsname_01326_tl} {Falmouth}
\tl_const:cn {c_phone_UK_ortsname_01327_tl} {Daventry}
\tl_const:cn {c_phone_UK_ortsname_01328_tl} {Fakenham}
\tl_const:cn {c_phone_UK_ortsname_01329_tl} {Fareham}
\tl_const:cn {c_phone_UK_ortsname_01330_tl} {Banchory}
\tl_const:cn {c_phone_UK_ortsname_01332_tl} {Derby}
\tl_const:cn {c_phone_UK_ortsname_01333_tl} {Anstruther}
\tl_const:cn {c_phone_UK_ortsname_01334_tl} {St~Andrews}
\tl_const:cn {c_phone_UK_ortsname_01335_tl} {Ashbourne}
\tl_const:cn {c_phone_UK_ortsname_01337_tl} {Ladybank}
\tl_const:cn {c_phone_UK_ortsname_01339_tl} {Aboyne/Ballater}
\tl_const:cn {c_phone_UK_ortsname_01340_tl} {Craigellachie}
\tl_const:cn {c_phone_UK_ortsname_01341_tl} {Barmouth}
\tl_const:cn {c_phone_UK_ortsname_01342_tl} {East~Grinstead}
\tl_const:cn {c_phone_UK_ortsname_01343_tl} {Elgin}
\tl_const:cn {c_phone_UK_ortsname_01344_tl} {Bracknell}
\tl_const:cn {c_phone_UK_ortsname_01346_tl} {Fraserburgh}
\tl_const:cn {c_phone_UK_ortsname_01347_tl} {Easingwold}
\tl_const:cn {c_phone_UK_ortsname_01348_tl} {Fishguard}
\tl_const:cn {c_phone_UK_ortsname_01349_tl} {Dingwall}
\tl_const:cn {c_phone_UK_ortsname_01350_tl} {Dunkeld}
\tl_const:cn {c_phone_UK_ortsname_01352_tl} {Mold}
\tl_const:cn {c_phone_UK_ortsname_01353_tl} {Ely}
\tl_const:cn {c_phone_UK_ortsname_01354_tl} {Chatteris}
\tl_const:cn {c_phone_UK_ortsname_01355_tl} {East~Kilbride}
\tl_const:cn {c_phone_UK_ortsname_01356_tl} {Brechin}
\tl_const:cn {c_phone_UK_ortsname_01357_tl} {Strathaven}
\tl_const:cn {c_phone_UK_ortsname_01358_tl} {Ellon}
\tl_const:cn {c_phone_UK_ortsname_01359_tl} {Pakenham}
\tl_const:cn {c_phone_UK_ortsname_01360_tl} {Killearn}
\tl_const:cn {c_phone_UK_ortsname_01361_tl} {Duns}
\tl_const:cn {c_phone_UK_ortsname_01362_tl} {Dereham}
\tl_const:cn {c_phone_UK_ortsname_01363_tl} {Crediton}
\tl_const:cn {c_phone_UK_ortsname_01364_tl} {Ashburton}
\tl_const:cn {c_phone_UK_ortsname_01366_tl} {Downham~Market}
\tl_const:cn {c_phone_UK_ortsname_01367_tl} {Faringdon}
\tl_const:cn {c_phone_UK_ortsname_01368_tl} {Dunbar}
\tl_const:cn {c_phone_UK_ortsname_01369_tl} {Dunoon}
\tl_const:cn {c_phone_UK_ortsname_01371_tl} {Great~Dunmow}
\tl_const:cn {c_phone_UK_ortsname_01372_tl} {Esher}
\tl_const:cn {c_phone_UK_ortsname_01373_tl} {Frome}
\tl_const:cn {c_phone_UK_ortsname_01375_tl} {Grays~Thurrock}
\tl_const:cn {c_phone_UK_ortsname_01376_tl} {Braintree}
\tl_const:cn {c_phone_UK_ortsname_01377_tl} {Driffield}
\tl_const:cn {c_phone_UK_ortsname_01379_tl} {Diss}
\tl_const:cn {c_phone_UK_ortsname_01380_tl} {Devizes}
\tl_const:cn {c_phone_UK_ortsname_01381_tl} {Fortrose}
\tl_const:cn {c_phone_UK_ortsname_01382_tl} {Dundee}
\tl_const:cn {c_phone_UK_ortsname_01383_tl} {Dunfermline}
\tl_const:cn {c_phone_UK_ortsname_01384_tl} {Dudley}
\tl_const:cn {c_phone_UK_ortsname_01386_tl} {Evesham}
\tl_const:cn {c_phone_UK_ortsname_01387_tl} {Dumfries}
\tl_const:cn {c_phone_UK_ortsname_013873_tl} {Langholm}
\tl_const:cn {c_phone_UK_ortsname_01388_tl} {Bishop~Auckland/Stanhope}
\tl_const:cn {c_phone_UK_ortsname_01389_tl} {Dumbarton}
\tl_const:cn {c_phone_UK_ortsname_01392_tl} {Exeter}
\tl_const:cn {c_phone_UK_ortsname_01394_tl} {Felixstowe}
\tl_const:cn {c_phone_UK_ortsname_01395_tl} {Budleigh~Salterton}
\tl_const:cn {c_phone_UK_ortsname_01397_tl} {Fort~William}
\tl_const:cn {c_phone_UK_ortsname_01398_tl} {Dulverton}
\tl_const:cn {c_phone_UK_ortsname_01400_tl} {Honington}
\tl_const:cn {c_phone_UK_ortsname_01403_tl} {Horsham}
\tl_const:cn {c_phone_UK_ortsname_01404_tl} {Honiton}
\tl_const:cn {c_phone_UK_ortsname_01405_tl} {Goole}
\tl_const:cn {c_phone_UK_ortsname_01406_tl} {Holbeach}
\tl_const:cn {c_phone_UK_ortsname_01407_tl} {Holyhead}
\tl_const:cn {c_phone_UK_ortsname_01408_tl} {Golspie}
\tl_const:cn {c_phone_UK_ortsname_01409_tl} {Holsworthy}
\tl_const:cn {c_phone_UK_ortsname_0141_tl} {Glasgow}
\tl_const:cn {c_phone_UK_ortsname_01420_tl} {Alton}
\tl_const:cn {c_phone_UK_ortsname_01422_tl} {Halifax}
\tl_const:cn {c_phone_UK_ortsname_01423_tl} {Boroughbridge/Harrogate}
\tl_const:cn {c_phone_UK_ortsname_01424_tl} {Hastings}
\tl_const:cn {c_phone_UK_ortsname_01425_tl} {Ringwood}
\tl_const:cn {c_phone_UK_ortsname_01427_tl} {Gainsborough}
\tl_const:cn {c_phone_UK_ortsname_01428_tl} {Haslemere}
\tl_const:cn {c_phone_UK_ortsname_01429_tl} {Hartlepool}
\tl_const:cn {c_phone_UK_ortsname_01430_tl} {Market~Weighton/North~Cave}
\tl_const:cn {c_phone_UK_ortsname_01431_tl} {Helmsdale}
\tl_const:cn {c_phone_UK_ortsname_01432_tl} {Hereford}
\tl_const:cn {c_phone_UK_ortsname_01433_tl} {Hathersage}
\tl_const:cn {c_phone_UK_ortsname_01434_tl} {Bellingham/Haltwhistle/Hexham}
\tl_const:cn {c_phone_UK_ortsname_01435_tl} {Heathfield}
\tl_const:cn {c_phone_UK_ortsname_01436_tl} {Helensburgh}
\tl_const:cn {c_phone_UK_ortsname_01437_tl} {Clynderwen/Haverfordwest}
\tl_const:cn {c_phone_UK_ortsname_01438_tl} {Stevenage}
\tl_const:cn {c_phone_UK_ortsname_01439_tl} {Helmsley}
\tl_const:cn {c_phone_UK_ortsname_01440_tl} {Haverhill}
\tl_const:cn {c_phone_UK_ortsname_01442_tl} {Hemel~Hempstead}
\tl_const:cn {c_phone_UK_ortsname_01443_tl} {Pontypridd}
\tl_const:cn {c_phone_UK_ortsname_01444_tl} {Haywards~Heath}
\tl_const:cn {c_phone_UK_ortsname_01445_tl} {Gairloch}
\tl_const:cn {c_phone_UK_ortsname_01446_tl} {Barry}
\tl_const:cn {c_phone_UK_ortsname_01449_tl} {Stowmarket}
\tl_const:cn {c_phone_UK_ortsname_01450_tl} {Hawick}
\tl_const:cn {c_phone_UK_ortsname_01451_tl} {Stow-on-the-Wold}
\tl_const:cn {c_phone_UK_ortsname_01452_tl} {Gloucester}
\tl_const:cn {c_phone_UK_ortsname_01453_tl} {Dursley}
\tl_const:cn {c_phone_UK_ortsname_01454_tl} {Chipping~Sodbury}
\tl_const:cn {c_phone_UK_ortsname_01455_tl} {Hinckley}
\tl_const:cn {c_phone_UK_ortsname_01456_tl} {Glenurquhart}
\tl_const:cn {c_phone_UK_ortsname_01457_tl} {Glossop}
\tl_const:cn {c_phone_UK_ortsname_01458_tl} {Glastonbury}
\tl_const:cn {c_phone_UK_ortsname_01460_tl} {Chard}
\tl_const:cn {c_phone_UK_ortsname_01461_tl} {Gretna}
\tl_const:cn {c_phone_UK_ortsname_01462_tl} {Hitchin}
\tl_const:cn {c_phone_UK_ortsname_01463_tl} {Inverness}
\tl_const:cn {c_phone_UK_ortsname_01464_tl} {Insch}
\tl_const:cn {c_phone_UK_ortsname_01465_tl} {Girvan}
\tl_const:cn {c_phone_UK_ortsname_01466_tl} {Huntly}
\tl_const:cn {c_phone_UK_ortsname_01467_tl} {Inverurie}
\tl_const:cn {c_phone_UK_ortsname_01469_tl} {Killingholme}
\tl_const:cn {c_phone_UK_ortsname_01470_tl} {Edinbane,~Isle~of~Skye}
\tl_const:cn {c_phone_UK_ortsname_01471_tl} {Broadford,~Isle~of~Skye}
\tl_const:cn {c_phone_UK_ortsname_01472_tl} {Grimsby}
\tl_const:cn {c_phone_UK_ortsname_01473_tl} {Ipswich}
\tl_const:cn {c_phone_UK_ortsname_01474_tl} {Gravesend}
\tl_const:cn {c_phone_UK_ortsname_01475_tl} {Greenock}
\tl_const:cn {c_phone_UK_ortsname_01476_tl} {Grantham}
\tl_const:cn {c_phone_UK_ortsname_01477_tl} {Holmes~Chapel}
\tl_const:cn {c_phone_UK_ortsname_01478_tl} {Portree,~Isle~of~Skye}
\tl_const:cn {c_phone_UK_ortsname_01479_tl} {Grantown-on-Spey}
\tl_const:cn {c_phone_UK_ortsname_01480_tl} {Huntingdon}
\tl_const:cn {c_phone_UK_ortsname_01481_tl} {Guernsey}
\tl_const:cn {c_phone_UK_ortsname_01482_tl} {Hull}
\tl_const:cn {c_phone_UK_ortsname_01483_tl} {Guildford}
\tl_const:cn {c_phone_UK_ortsname_01484_tl} {Huddersfield}
\tl_const:cn {c_phone_UK_ortsname_01485_tl} {Hunstanton}
\tl_const:cn {c_phone_UK_ortsname_01487_tl} {Warboys}
\tl_const:cn {c_phone_UK_ortsname_01488_tl} {Hungerford}
\tl_const:cn {c_phone_UK_ortsname_01489_tl} {Bishops~Waltham}
\tl_const:cn {c_phone_UK_ortsname_01490_tl} {Corwen}
\tl_const:cn {c_phone_UK_ortsname_01491_tl} {Henley-on-Thames}
\tl_const:cn {c_phone_UK_ortsname_01492_tl} {Colwyn~Bay}
\tl_const:cn {c_phone_UK_ortsname_01493_tl} {Great~Yarmouth}
\tl_const:cn {c_phone_UK_ortsname_01494_tl} {High~Wycombe}
\tl_const:cn {c_phone_UK_ortsname_01495_tl} {Pontypool}
\tl_const:cn {c_phone_UK_ortsname_01496_tl} {Islay~and~Jura}
\tl_const:cn {c_phone_UK_ortsname_01497_tl} {Hay-on-Wye}
\tl_const:cn {c_phone_UK_ortsname_01499_tl} {Inveraray}
\tl_const:cn {c_phone_UK_ortsname_01501_tl} {Harthill}
\tl_const:cn {c_phone_UK_ortsname_01502_tl} {Lowestoft}
\tl_const:cn {c_phone_UK_ortsname_01503_tl} {Looe}
\tl_const:cn {c_phone_UK_ortsname_01505_tl} {Johnstone}
\tl_const:cn {c_phone_UK_ortsname_01506_tl} {Bathgate}
\tl_const:cn {c_phone_UK_ortsname_01507_tl} {Alford/Louth/Horncastle}
\tl_const:cn {c_phone_UK_ortsname_01508_tl} {Brooke}
\tl_const:cn {c_phone_UK_ortsname_01509_tl} {Loughborough}
\tl_const:cn {c_phone_UK_ortsname_0151_tl} {Liverpool}
\tl_const:cn {c_phone_UK_ortsname_01520_tl} {Lochcarron}
\tl_const:cn {c_phone_UK_ortsname_01522_tl} {Lincoln}
\tl_const:cn {c_phone_UK_ortsname_01524_tl} {Lancaster}
\tl_const:cn {c_phone_UK_ortsname_015242_tl} {Hornby}
\tl_const:cn {c_phone_UK_ortsname_01525_tl} {Leighton~Buzzard}
\tl_const:cn {c_phone_UK_ortsname_01526_tl} {Martin}
\tl_const:cn {c_phone_UK_ortsname_01527_tl} {Redditch}
\tl_const:cn {c_phone_UK_ortsname_01528_tl} {Laggan}
\tl_const:cn {c_phone_UK_ortsname_01529_tl} {Sleaford}
\tl_const:cn {c_phone_UK_ortsname_01530_tl} {Coalville}
\tl_const:cn {c_phone_UK_ortsname_01531_tl} {Ledbury}
\tl_const:cn {c_phone_UK_ortsname_01534_tl} {Jersey}
\tl_const:cn {c_phone_UK_ortsname_01535_tl} {Keighley}
\tl_const:cn {c_phone_UK_ortsname_01536_tl} {Kettering}
\tl_const:cn {c_phone_UK_ortsname_01538_tl} {Leek}
\tl_const:cn {c_phone_UK_ortsname_01539_tl} {Kendal}
\tl_const:cn {c_phone_UK_ortsname_015394_tl} {Hawkshead}
\tl_const:cn {c_phone_UK_ortsname_015395_tl} {Grange-Over-Sands}
\tl_const:cn {c_phone_UK_ortsname_015396_tl} {Sedbergh}
\tl_const:cn {c_phone_UK_ortsname_01540_tl} {Kingussie}
\tl_const:cn {c_phone_UK_ortsname_01542_tl} {Keith}
\tl_const:cn {c_phone_UK_ortsname_01543_tl} {Cannock}
\tl_const:cn {c_phone_UK_ortsname_01544_tl} {Kington}
\tl_const:cn {c_phone_UK_ortsname_01545_tl} {Llanarth}
\tl_const:cn {c_phone_UK_ortsname_01546_tl} {Lochgilphead}
\tl_const:cn {c_phone_UK_ortsname_01547_tl} {Knighton}
\tl_const:cn {c_phone_UK_ortsname_01548_tl} {Kingsbridge}
\tl_const:cn {c_phone_UK_ortsname_01549_tl} {Lairg}
\tl_const:cn {c_phone_UK_ortsname_01550_tl} {Llandovery}
\tl_const:cn {c_phone_UK_ortsname_01553_tl} {King's~Lynn}
\tl_const:cn {c_phone_UK_ortsname_01554_tl} {Llanelli}
\tl_const:cn {c_phone_UK_ortsname_01555_tl} {Lanark}
\tl_const:cn {c_phone_UK_ortsname_01556_tl} {Castle~Douglas}
\tl_const:cn {c_phone_UK_ortsname_01557_tl} {Kirkcudbright}
\tl_const:cn {c_phone_UK_ortsname_01558_tl} {Llandeilo}
\tl_const:cn {c_phone_UK_ortsname_01559_tl} {Llandysul}
\tl_const:cn {c_phone_UK_ortsname_01560_tl} {Moscow}
\tl_const:cn {c_phone_UK_ortsname_01561_tl} {Laurencekirk}
\tl_const:cn {c_phone_UK_ortsname_01562_tl} {Kidderminster}
\tl_const:cn {c_phone_UK_ortsname_01563_tl} {Kilmarnock}
\tl_const:cn {c_phone_UK_ortsname_01564_tl} {Lapworth}
\tl_const:cn {c_phone_UK_ortsname_01565_tl} {Knutsford}
\tl_const:cn {c_phone_UK_ortsname_01566_tl} {Launceston}
\tl_const:cn {c_phone_UK_ortsname_01567_tl} {Killin}
\tl_const:cn {c_phone_UK_ortsname_01568_tl} {Leominster}
\tl_const:cn {c_phone_UK_ortsname_01569_tl} {Stonehaven}
\tl_const:cn {c_phone_UK_ortsname_01570_tl} {Lampeter}
\tl_const:cn {c_phone_UK_ortsname_01571_tl} {Lochinver}
\tl_const:cn {c_phone_UK_ortsname_01572_tl} {Oakham}
\tl_const:cn {c_phone_UK_ortsname_01573_tl} {Kelso}
\tl_const:cn {c_phone_UK_ortsname_01575_tl} {Kirriemuir}
\tl_const:cn {c_phone_UK_ortsname_01576_tl} {Lockerbie}
\tl_const:cn {c_phone_UK_ortsname_01577_tl} {Kinross}
\tl_const:cn {c_phone_UK_ortsname_01578_tl} {Lauder}
\tl_const:cn {c_phone_UK_ortsname_01579_tl} {Liskeard}
\tl_const:cn {c_phone_UK_ortsname_01580_tl} {Cranbrook}
\tl_const:cn {c_phone_UK_ortsname_01581_tl} {New~Luce}
\tl_const:cn {c_phone_UK_ortsname_01582_tl} {Luton}
\tl_const:cn {c_phone_UK_ortsname_01583_tl} {Carradale}
\tl_const:cn {c_phone_UK_ortsname_01584_tl} {Ludlow}
\tl_const:cn {c_phone_UK_ortsname_01586_tl} {Campbeltown}
\tl_const:cn {c_phone_UK_ortsname_01588_tl} {Bishops~Castle}
\tl_const:cn {c_phone_UK_ortsname_01590_tl} {Lymington}
\tl_const:cn {c_phone_UK_ortsname_01591_tl} {Llanwrtyd~Wells}
\tl_const:cn {c_phone_UK_ortsname_01592_tl} {Kirkcaldy}
\tl_const:cn {c_phone_UK_ortsname_01593_tl} {Lybster}
\tl_const:cn {c_phone_UK_ortsname_01594_tl} {Lydney}
\tl_const:cn {c_phone_UK_ortsname_01595_tl} {Lerwick,~Shetland~Islands}
\tl_const:cn {c_phone_UK_ortsname_01597_tl} {Llandrindod~Wells}
\tl_const:cn {c_phone_UK_ortsname_01598_tl} {Lynton}
\tl_const:cn {c_phone_UK_ortsname_01599_tl} {Kyle}
\tl_const:cn {c_phone_UK_ortsname_01600_tl} {Monmouth}
\tl_const:cn {c_phone_UK_ortsname_01603_tl} {Norwich}
\tl_const:cn {c_phone_UK_ortsname_01604_tl} {Northampton}
\tl_const:cn {c_phone_UK_ortsname_01606_tl} {Northwich}
\tl_const:cn {c_phone_UK_ortsname_01608_tl} {Chipping~Norton}
\tl_const:cn {c_phone_UK_ortsname_01609_tl} {Northallerton}
\tl_const:cn {c_phone_UK_ortsname_0161_tl} {Manchester}
\tl_const:cn {c_phone_UK_ortsname_01620_tl} {North~Berwick}
\tl_const:cn {c_phone_UK_ortsname_01621_tl} {Maldon}
\tl_const:cn {c_phone_UK_ortsname_01622_tl} {Maidstone}
\tl_const:cn {c_phone_UK_ortsname_01623_tl} {Mansfield}
\tl_const:cn {c_phone_UK_ortsname_01624_tl} {Isle~of~Man}
\tl_const:cn {c_phone_UK_ortsname_01625_tl} {Macclesfield}
\tl_const:cn {c_phone_UK_ortsname_01626_tl} {Newton~Abbot}
\tl_const:cn {c_phone_UK_ortsname_01628_tl} {Maidenhead}
\tl_const:cn {c_phone_UK_ortsname_01629_tl} {Matlock}
\tl_const:cn {c_phone_UK_ortsname_01630_tl} {Market~Drayton}
\tl_const:cn {c_phone_UK_ortsname_01631_tl} {Oban}
\tl_const:cn {c_phone_UK_ortsname_01633_tl} {Newport}
\tl_const:cn {c_phone_UK_ortsname_01634_tl} {Medway}
\tl_const:cn {c_phone_UK_ortsname_01635_tl} {Newbury}
\tl_const:cn {c_phone_UK_ortsname_01636_tl} {Newark}
\tl_const:cn {c_phone_UK_ortsname_01637_tl} {Newquay}
\tl_const:cn {c_phone_UK_ortsname_01638_tl} {Newmarket}
\tl_const:cn {c_phone_UK_ortsname_01639_tl} {Neath}
\tl_const:cn {c_phone_UK_ortsname_01641_tl} {Strathy}
\tl_const:cn {c_phone_UK_ortsname_01642_tl} {Middlesbrough}
\tl_const:cn {c_phone_UK_ortsname_01643_tl} {Minehead}
\tl_const:cn {c_phone_UK_ortsname_01644_tl} {New~Galloway}
\tl_const:cn {c_phone_UK_ortsname_01646_tl} {Milford~Haven}
\tl_const:cn {c_phone_UK_ortsname_01647_tl} {Moretonhampstead}
\tl_const:cn {c_phone_UK_ortsname_01650_tl} {Cemmaes~Road}
\tl_const:cn {c_phone_UK_ortsname_01651_tl} {Oldmeldrum}
\tl_const:cn {c_phone_UK_ortsname_01652_tl} {Brigg}
\tl_const:cn {c_phone_UK_ortsname_01653_tl} {Malton}
\tl_const:cn {c_phone_UK_ortsname_01654_tl} {Machynlleth}
\tl_const:cn {c_phone_UK_ortsname_01655_tl} {Maybole}
\tl_const:cn {c_phone_UK_ortsname_01656_tl} {Bridgend}
\tl_const:cn {c_phone_UK_ortsname_01659_tl} {Sanquhar}
\tl_const:cn {c_phone_UK_ortsname_01661_tl} {Prudhoe}
\tl_const:cn {c_phone_UK_ortsname_01663_tl} {New~Mills}
\tl_const:cn {c_phone_UK_ortsname_01664_tl} {Melton~Mowbray}
\tl_const:cn {c_phone_UK_ortsname_01665_tl} {Alnwick}
\tl_const:cn {c_phone_UK_ortsname_01666_tl} {Malmesbury}
\tl_const:cn {c_phone_UK_ortsname_01667_tl} {Nairn}
\tl_const:cn {c_phone_UK_ortsname_01668_tl} {Bamburgh}
\tl_const:cn {c_phone_UK_ortsname_01669_tl} {Rothbury}
\tl_const:cn {c_phone_UK_ortsname_01670_tl} {Morpeth}
\tl_const:cn {c_phone_UK_ortsname_01671_tl} {Newton~Stewart}
\tl_const:cn {c_phone_UK_ortsname_01672_tl} {Marlborough}
\tl_const:cn {c_phone_UK_ortsname_01673_tl} {Market~Rasen}
\tl_const:cn {c_phone_UK_ortsname_01674_tl} {Montrose}
\tl_const:cn {c_phone_UK_ortsname_01675_tl} {Coleshill}
\tl_const:cn {c_phone_UK_ortsname_01676_tl} {Meriden}
\tl_const:cn {c_phone_UK_ortsname_01677_tl} {Bedale}
\tl_const:cn {c_phone_UK_ortsname_01678_tl} {Bala}
\tl_const:cn {c_phone_UK_ortsname_01680_tl} {Craignure,~Isle~of~Mull}
\tl_const:cn {c_phone_UK_ortsname_01681_tl} {Fionnphort,~Isle~of~Mull}
\tl_const:cn {c_phone_UK_ortsname_01683_tl} {Moffat}
\tl_const:cn {c_phone_UK_ortsname_01684_tl} {Malvern}
\tl_const:cn {c_phone_UK_ortsname_01685_tl} {Merthyr~Tydfil}
\tl_const:cn {c_phone_UK_ortsname_01686_tl} {Llanidloes/Newtown}
\tl_const:cn {c_phone_UK_ortsname_01687_tl} {Mallaig}
\tl_const:cn {c_phone_UK_ortsname_01688_tl} {Tobermory,~Isle~of~Mull}
\tl_const:cn {c_phone_UK_ortsname_01689_tl} {Orpington}
\tl_const:cn {c_phone_UK_ortsname_01690_tl} {Betws-y-Coed}
\tl_const:cn {c_phone_UK_ortsname_01691_tl} {Oswestry}
\tl_const:cn {c_phone_UK_ortsname_01692_tl} {North~Walsham}
\tl_const:cn {c_phone_UK_ortsname_01694_tl} {Church~Stretton}
\tl_const:cn {c_phone_UK_ortsname_01695_tl} {Skelmersdale}
\tl_const:cn {c_phone_UK_ortsname_01697_tl} {Brampton}
\tl_const:cn {c_phone_UK_ortsname_016973_tl} {Wigton}
\tl_const:cn {c_phone_UK_ortsname_016974_tl} {Raughton~Head}
\tl_const:cn {c_phone_UK_ortsname_016977_tl} {Brampton}
\tl_const:cn {c_phone_UK_ortsname_01698_tl} {Motherwell}
\tl_const:cn {c_phone_UK_ortsname_01700_tl} {Rothesay}
\tl_const:cn {c_phone_UK_ortsname_01702_tl} {Southend-on-Sea}
\tl_const:cn {c_phone_UK_ortsname_01704_tl} {Southport}
\tl_const:cn {c_phone_UK_ortsname_01706_tl} {Rochdale}
\tl_const:cn {c_phone_UK_ortsname_01707_tl} {Welwyn~Garden~City}
\tl_const:cn {c_phone_UK_ortsname_01708_tl} {Romford}
\tl_const:cn {c_phone_UK_ortsname_01709_tl} {Rotherham}
\tl_const:cn {c_phone_UK_ortsname_01720_tl} {Isles~of~Scilly}
\tl_const:cn {c_phone_UK_ortsname_01721_tl} {Peebles}
\tl_const:cn {c_phone_UK_ortsname_01722_tl} {Salisbury}
\tl_const:cn {c_phone_UK_ortsname_01723_tl} {Scarborough}
\tl_const:cn {c_phone_UK_ortsname_01724_tl} {Scunthorpe}
\tl_const:cn {c_phone_UK_ortsname_01725_tl} {Rockbourne}
\tl_const:cn {c_phone_UK_ortsname_01726_tl} {St~Austell}
\tl_const:cn {c_phone_UK_ortsname_01727_tl} {St~Albans}
\tl_const:cn {c_phone_UK_ortsname_01728_tl} {Saxmundham}
\tl_const:cn {c_phone_UK_ortsname_01729_tl} {Settle}
\tl_const:cn {c_phone_UK_ortsname_01730_tl} {Petersfield}
\tl_const:cn {c_phone_UK_ortsname_01732_tl} {Sevenoaks}
\tl_const:cn {c_phone_UK_ortsname_01733_tl} {Peterborough}
\tl_const:cn {c_phone_UK_ortsname_01736_tl} {Penzance}
\tl_const:cn {c_phone_UK_ortsname_01737_tl} {Redhill}
\tl_const:cn {c_phone_UK_ortsname_01738_tl} {Perth}
\tl_const:cn {c_phone_UK_ortsname_01740_tl} {Sedgefield}
\tl_const:cn {c_phone_UK_ortsname_01743_tl} {Shrewsbury}
\tl_const:cn {c_phone_UK_ortsname_01744_tl} {St~Helens}
\tl_const:cn {c_phone_UK_ortsname_01745_tl} {Rhyl}
\tl_const:cn {c_phone_UK_ortsname_01746_tl} {Bridgnorth}
\tl_const:cn {c_phone_UK_ortsname_01747_tl} {Shaftesbury}
\tl_const:cn {c_phone_UK_ortsname_01748_tl} {Richmond}
\tl_const:cn {c_phone_UK_ortsname_01749_tl} {Shepton~Mallet}
\tl_const:cn {c_phone_UK_ortsname_01750_tl} {Selkirk}
\tl_const:cn {c_phone_UK_ortsname_01751_tl} {Pickering}
\tl_const:cn {c_phone_UK_ortsname_01752_tl} {Plymouth}
\tl_const:cn {c_phone_UK_ortsname_01753_tl} {Slough}
\tl_const:cn {c_phone_UK_ortsname_01754_tl} {Skegness}
\tl_const:cn {c_phone_UK_ortsname_01756_tl} {Skipton}
\tl_const:cn {c_phone_UK_ortsname_01757_tl} {Selby}
\tl_const:cn {c_phone_UK_ortsname_01758_tl} {Pwllheli}
\tl_const:cn {c_phone_UK_ortsname_01759_tl} {Pocklington}
\tl_const:cn {c_phone_UK_ortsname_01760_tl} {Swaffham}
\tl_const:cn {c_phone_UK_ortsname_01761_tl} {Temple~Cloud}
\tl_const:cn {c_phone_UK_ortsname_01763_tl} {Royston}
\tl_const:cn {c_phone_UK_ortsname_01764_tl} {Crieff}
\tl_const:cn {c_phone_UK_ortsname_01765_tl} {Ripon}
\tl_const:cn {c_phone_UK_ortsname_01766_tl} {Porthmadog}
\tl_const:cn {c_phone_UK_ortsname_01767_tl} {Sandy}
\tl_const:cn {c_phone_UK_ortsname_01768_tl} {Penrith}
\tl_const:cn {c_phone_UK_ortsname_017683_tl} {Appleby}
\tl_const:cn {c_phone_UK_ortsname_017684_tl} {Pooley~Bridge}
\tl_const:cn {c_phone_UK_ortsname_017687_tl} {Keswick}
\tl_const:cn {c_phone_UK_ortsname_01769_tl} {South~Molton}
\tl_const:cn {c_phone_UK_ortsname_01770_tl} {Isle~of~Arran}
\tl_const:cn {c_phone_UK_ortsname_01771_tl} {Maud}
\tl_const:cn {c_phone_UK_ortsname_01772_tl} {Preston}
\tl_const:cn {c_phone_UK_ortsname_01773_tl} {Ripley}
\tl_const:cn {c_phone_UK_ortsname_01775_tl} {Spalding}
\tl_const:cn {c_phone_UK_ortsname_01776_tl} {Stranraer}
\tl_const:cn {c_phone_UK_ortsname_01777_tl} {Retford}
\tl_const:cn {c_phone_UK_ortsname_01778_tl} {Bourne}
\tl_const:cn {c_phone_UK_ortsname_01779_tl} {Peterhead}
\tl_const:cn {c_phone_UK_ortsname_01780_tl} {Stamford}
\tl_const:cn {c_phone_UK_ortsname_01782_tl} {Stoke-on-Trent}
\tl_const:cn {c_phone_UK_ortsname_01784_tl} {Staines}
\tl_const:cn {c_phone_UK_ortsname_01785_tl} {Stafford}
\tl_const:cn {c_phone_UK_ortsname_01786_tl} {Stirling}
\tl_const:cn {c_phone_UK_ortsname_01787_tl} {Sudbury}
\tl_const:cn {c_phone_UK_ortsname_01788_tl} {Rugby}
\tl_const:cn {c_phone_UK_ortsname_01789_tl} {Stratford-upon-Avon}
\tl_const:cn {c_phone_UK_ortsname_01790_tl} {Spilsby}
\tl_const:cn {c_phone_UK_ortsname_01792_tl} {Swansea}
\tl_const:cn {c_phone_UK_ortsname_01793_tl} {Swindon}
\tl_const:cn {c_phone_UK_ortsname_01794_tl} {Romsey}
\tl_const:cn {c_phone_UK_ortsname_01795_tl} {Sittingbourne}
\tl_const:cn {c_phone_UK_ortsname_01796_tl} {Pitlochry}
\tl_const:cn {c_phone_UK_ortsname_01797_tl} {Rye}
\tl_const:cn {c_phone_UK_ortsname_01798_tl} {Pulborough}
\tl_const:cn {c_phone_UK_ortsname_01799_tl} {Saffron~Walden}
\tl_const:cn {c_phone_UK_ortsname_01803_tl} {Torquay}
\tl_const:cn {c_phone_UK_ortsname_01805_tl} {Torrington}
\tl_const:cn {c_phone_UK_ortsname_01806_tl} {Sullom~Voe,~Shetland~Islands}
\tl_const:cn {c_phone_UK_ortsname_01807_tl} {Ballindalloch}
\tl_const:cn {c_phone_UK_ortsname_01808_tl} {Tomatin}
\tl_const:cn {c_phone_UK_ortsname_01809_tl} {Tomdoun}
\tl_const:cn {c_phone_UK_ortsname_01821_tl} {Kinrossie}
\tl_const:cn {c_phone_UK_ortsname_01822_tl} {Tavistock}
\tl_const:cn {c_phone_UK_ortsname_01823_tl} {Taunton}
\tl_const:cn {c_phone_UK_ortsname_01824_tl} {Ruthin}
\tl_const:cn {c_phone_UK_ortsname_01825_tl} {Uckfield}
\tl_const:cn {c_phone_UK_ortsname_01827_tl} {Tamworth}
\tl_const:cn {c_phone_UK_ortsname_01828_tl} {Coupar~Angus}
\tl_const:cn {c_phone_UK_ortsname_01829_tl} {Tarporley}
\tl_const:cn {c_phone_UK_ortsname_01830_tl} {Kirkwhelpington}
\tl_const:cn {c_phone_UK_ortsname_01832_tl} {Clopton}
\tl_const:cn {c_phone_UK_ortsname_01833_tl} {Barnard~Castle}
\tl_const:cn {c_phone_UK_ortsname_01834_tl} {Narberth}
\tl_const:cn {c_phone_UK_ortsname_01835_tl} {St~Boswells}
\tl_const:cn {c_phone_UK_ortsname_01837_tl} {Okehampton}
\tl_const:cn {c_phone_UK_ortsname_01838_tl} {Dalmally}
\tl_const:cn {c_phone_UK_ortsname_01840_tl} {Camelford}
\tl_const:cn {c_phone_UK_ortsname_01841_tl} {Padstow}
\tl_const:cn {c_phone_UK_ortsname_01842_tl} {Thetford}
\tl_const:cn {c_phone_UK_ortsname_01843_tl} {Thanet}
\tl_const:cn {c_phone_UK_ortsname_01844_tl} {Thame}
\tl_const:cn {c_phone_UK_ortsname_01845_tl} {Thirsk}
\tl_const:cn {c_phone_UK_ortsname_01847_tl} {Thurso/Tongue}
\tl_const:cn {c_phone_UK_ortsname_01848_tl} {Thornhill}
\tl_const:cn {c_phone_UK_ortsname_01851_tl} {Lewis~and~Great~Bernera,~Outer~Hebrides}
\tl_const:cn {c_phone_UK_ortsname_01852_tl} {Kilmelford}
\tl_const:cn {c_phone_UK_ortsname_01854_tl} {Ullapool}
\tl_const:cn {c_phone_UK_ortsname_01855_tl} {Ballachulish}
\tl_const:cn {c_phone_UK_ortsname_01856_tl} {Orkney}
\tl_const:cn {c_phone_UK_ortsname_01857_tl} {Sanday}
\tl_const:cn {c_phone_UK_ortsname_01858_tl} {Market~Harborough}
\tl_const:cn {c_phone_UK_ortsname_01859_tl} {Harris,~Outer~Hebrides}
\tl_const:cn {c_phone_UK_ortsname_01862_tl} {Tain}
\tl_const:cn {c_phone_UK_ortsname_01863_tl} {Ardgay}
\tl_const:cn {c_phone_UK_ortsname_01864_tl} {Abington}
\tl_const:cn {c_phone_UK_ortsname_01865_tl} {Oxford}
\tl_const:cn {c_phone_UK_ortsname_01866_tl} {Kilchrenan}
\tl_const:cn {c_phone_UK_ortsname_01869_tl} {Bicester}
\tl_const:cn {c_phone_UK_ortsname_01870_tl} {Benebecula,~Outer~Hebrides}
\tl_const:cn {c_phone_UK_ortsname_01871_tl} {Barra,~Outer~Hebrides}
\tl_const:cn {c_phone_UK_ortsname_01872_tl} {Truro}
\tl_const:cn {c_phone_UK_ortsname_01873_tl} {Abergavenny}
\tl_const:cn {c_phone_UK_ortsname_01874_tl} {Brecon}
\tl_const:cn {c_phone_UK_ortsname_01875_tl} {Tranent}
\tl_const:cn {c_phone_UK_ortsname_01876_tl} {North~Uist,~Outer~Hebrides}
\tl_const:cn {c_phone_UK_ortsname_01877_tl} {Callander}
\tl_const:cn {c_phone_UK_ortsname_01878_tl} {South~Uist,~Outer~Hebrides}
\tl_const:cn {c_phone_UK_ortsname_01879_tl} {Tiree~and~Coll,~Inner~Hebrides}
\tl_const:cn {c_phone_UK_ortsname_01880_tl} {Tarbert}
\tl_const:cn {c_phone_UK_ortsname_01882_tl} {Kinloch~Rannoch}
\tl_const:cn {c_phone_UK_ortsname_01883_tl} {Caterham}
\tl_const:cn {c_phone_UK_ortsname_01884_tl} {Tiverton}
\tl_const:cn {c_phone_UK_ortsname_01885_tl} {Bromyard}
\tl_const:cn {c_phone_UK_ortsname_01886_tl} {Knightwick}
\tl_const:cn {c_phone_UK_ortsname_01887_tl} {Aberfeldy}
\tl_const:cn {c_phone_UK_ortsname_01888_tl} {Turriff}
\tl_const:cn {c_phone_UK_ortsname_01889_tl} {Rugeley}
\tl_const:cn {c_phone_UK_ortsname_01890_tl} {Ayton/Coldstream}
\tl_const:cn {c_phone_UK_ortsname_01892_tl} {Tunbridge~Wells}
\tl_const:cn {c_phone_UK_ortsname_01895_tl} {Uxbridge}
\tl_const:cn {c_phone_UK_ortsname_01896_tl} {Galashiels}
\tl_const:cn {c_phone_UK_ortsname_01899_tl} {Biggar}
\tl_const:cn {c_phone_UK_ortsname_01900_tl} {Workington}
\tl_const:cn {c_phone_UK_ortsname_01902_tl} {Wolverhampton}
\tl_const:cn {c_phone_UK_ortsname_01903_tl} {Worthing}
\tl_const:cn {c_phone_UK_ortsname_01904_tl} {York}
\tl_const:cn {c_phone_UK_ortsname_01905_tl} {Worcester}
\tl_const:cn {c_phone_UK_ortsname_01908_tl} {Milton~Keynes}
\tl_const:cn {c_phone_UK_ortsname_01909_tl} {Worksop}
\tl_const:cn {c_phone_UK_ortsname_0191_tl} {Tyneside/Durham/Sunderland}
\tl_const:cn {c_phone_UK_ortsname_01920_tl} {Ware}
\tl_const:cn {c_phone_UK_ortsname_01922_tl} {Walsall}
\tl_const:cn {c_phone_UK_ortsname_01923_tl} {Watford}
\tl_const:cn {c_phone_UK_ortsname_01924_tl} {Wakefield}
\tl_const:cn {c_phone_UK_ortsname_01925_tl} {Warrington}
\tl_const:cn {c_phone_UK_ortsname_01926_tl} {Warwick}
\tl_const:cn {c_phone_UK_ortsname_01928_tl} {Runcorn}
\tl_const:cn {c_phone_UK_ortsname_01929_tl} {Wareham}
\tl_const:cn {c_phone_UK_ortsname_01931_tl} {Shap}
\tl_const:cn {c_phone_UK_ortsname_01932_tl} {Weybridge}
\tl_const:cn {c_phone_UK_ortsname_01933_tl} {Wellingborough}
\tl_const:cn {c_phone_UK_ortsname_01934_tl} {Weston-Super-Mare}
\tl_const:cn {c_phone_UK_ortsname_01935_tl} {Yeovil}
\tl_const:cn {c_phone_UK_ortsname_01937_tl} {Wetherby}
\tl_const:cn {c_phone_UK_ortsname_01938_tl} {Welshpool}
\tl_const:cn {c_phone_UK_ortsname_01939_tl} {Wem}
\tl_const:cn {c_phone_UK_ortsname_01942_tl} {Wigan}
\tl_const:cn {c_phone_UK_ortsname_01943_tl} {Guiseley}
\tl_const:cn {c_phone_UK_ortsname_01944_tl} {West~Heslerton}
\tl_const:cn {c_phone_UK_ortsname_01945_tl} {Wisbech}
\tl_const:cn {c_phone_UK_ortsname_01946_tl} {Whitehaven}
\tl_const:cn {c_phone_UK_ortsname_019467_tl} {Gosforth}
\tl_const:cn {c_phone_UK_ortsname_01947_tl} {Whitby}
\tl_const:cn {c_phone_UK_ortsname_01948_tl} {Whitchurch}
\tl_const:cn {c_phone_UK_ortsname_01949_tl} {Whatton}
\tl_const:cn {c_phone_UK_ortsname_01950_tl} {Sandwick,~Shetland~Islands}
\tl_const:cn {c_phone_UK_ortsname_01951_tl} {Colonsay}
\tl_const:cn {c_phone_UK_ortsname_01952_tl} {Telford}
\tl_const:cn {c_phone_UK_ortsname_01953_tl} {Wymondham}
\tl_const:cn {c_phone_UK_ortsname_01954_tl} {Madingley}
\tl_const:cn {c_phone_UK_ortsname_01955_tl} {Wick}
\tl_const:cn {c_phone_UK_ortsname_01957_tl} {Mid~Yell,~Shetland~Islands}
\tl_const:cn {c_phone_UK_ortsname_01959_tl} {Westerham}
\tl_const:cn {c_phone_UK_ortsname_01962_tl} {Winchester}
\tl_const:cn {c_phone_UK_ortsname_01963_tl} {Wincanton}
\tl_const:cn {c_phone_UK_ortsname_01964_tl} {Hornsea/Patrington}
\tl_const:cn {c_phone_UK_ortsname_01967_tl} {Strontian}
\tl_const:cn {c_phone_UK_ortsname_01968_tl} {Penicuik}
\tl_const:cn {c_phone_UK_ortsname_01969_tl} {Leyburn}
\tl_const:cn {c_phone_UK_ortsname_01970_tl} {Aberystwyth}
\tl_const:cn {c_phone_UK_ortsname_01971_tl} {Scourie}
\tl_const:cn {c_phone_UK_ortsname_01972_tl} {Glenborrodale}
\tl_const:cn {c_phone_UK_ortsname_01974_tl} {Llanon}
\tl_const:cn {c_phone_UK_ortsname_01975_tl} {Alford~(Aberdeen)/Strathdon}
\tl_const:cn {c_phone_UK_ortsname_01977_tl} {Pontefract}
\tl_const:cn {c_phone_UK_ortsname_01978_tl} {Wrexham}
\tl_const:cn {c_phone_UK_ortsname_01980_tl} {Amesbury}
\tl_const:cn {c_phone_UK_ortsname_01981_tl} {Wormbridge}
\tl_const:cn {c_phone_UK_ortsname_01982_tl} {Builth~Wells}
\tl_const:cn {c_phone_UK_ortsname_01983_tl} {Isle~of~Wight}
\tl_const:cn {c_phone_UK_ortsname_01984_tl} {Watchet}
\tl_const:cn {c_phone_UK_ortsname_01985_tl} {Warminster}
\tl_const:cn {c_phone_UK_ortsname_01986_tl} {Bungay}
\tl_const:cn {c_phone_UK_ortsname_01987_tl} {Ebbsfleet}
\tl_const:cn {c_phone_UK_ortsname_01988_tl} {Wigtown}
\tl_const:cn {c_phone_UK_ortsname_01989_tl} {Ross-on-Wye}
\tl_const:cn {c_phone_UK_ortsname_01992_tl} {Lea~Valley}
\tl_const:cn {c_phone_UK_ortsname_01993_tl} {Witney}
\tl_const:cn {c_phone_UK_ortsname_01994_tl} {St~Clears}
\tl_const:cn {c_phone_UK_ortsname_01995_tl} {Garstang}
\tl_const:cn {c_phone_UK_ortsname_01997_tl} {Strathpeffer}
\tl_const:cn {c_phone_UK_ortsname_020_tl} {London}
\tl_const:cn {c_phone_UK_ortsname_023_tl} {Southampton/Portsmouth}
\tl_const:cn {c_phone_UK_ortsname_024_tl} {Coventry}
\tl_const:cn {c_phone_UK_ortsname_028_tl} {Northern~Ireland}
\tl_const:cn {c_phone_UK_ortsname_029_tl} {Cardiff}
\tl_const:cn {c_phone_UK_ortsname_0300_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0303_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0306_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0330_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0331_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0333_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0343_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0344_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0345_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0370_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0371_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_0372_tl} {Non-geographic~number}
\tl_const:cn {c_phone_UK_ortsname_05511_tl} {Corporate~number}
\tl_const:cn {c_phone_UK_ortsname_05516_tl} {Corporate~number}
\tl_const:cn {c_phone_UK_ortsname_05555_tl} {Corporate~number}
\tl_const:cn {c_phone_UK_ortsname_05588_tl} {Corporate~number}
\tl_const:cn {c_phone_UK_ortsname_05600_tl} {Electronic~communications~service}
\tl_const:cn {c_phone_UK_ortsname_05601_tl} {Electronic~communications~service}
\tl_const:cn {c_phone_UK_ortsname_05602_tl} {Electronic~communications~service}
\tl_const:cn {c_phone_UK_ortsname_05603_tl} {Electronic~communications~service}
\tl_const:cn {c_phone_UK_ortsname_05604_tl} {Electronic~communications~service}
\tl_const:cn {c_phone_UK_ortsname_07000_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07002_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07003_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07004_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07005_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07006_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07008_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07009_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07010_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07011_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07012_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07013_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07014_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07015_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07016_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07017_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07018_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07019_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07021_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07022_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07023_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07024_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07026_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07027_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07028_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07029_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07030_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07031_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07032_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07033_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07034_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07035_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07036_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07037_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07038_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07039_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07040_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07041_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07042_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07043_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07044_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07045_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07046_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07047_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07048_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07049_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07052_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07053_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07054_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07055_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07056_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07057_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07058_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07059_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07060_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07061_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07062_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07063_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07064_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07065_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07066_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07067_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07068_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07069_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07070_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07071_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07072_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07073_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07074_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07076_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07077_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07078_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07079_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07080_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07081_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07082_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07083_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07084_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07085_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07086_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07087_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07088_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07089_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07090_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07091_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07093_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07094_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07096_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07098_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07099_tl} {Personal~number}
\tl_const:cn {c_phone_UK_ortsname_07106_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07107_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07300_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07301_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07302_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07303_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07304_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07305_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07306_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07307_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07308_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07309_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07310_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07311_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07312_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07340_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07341_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07342_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07354_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07355_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07356_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07357_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07358_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07359_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07360_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07361_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07362_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07363_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07364_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07365_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07366_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07367_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07368_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07369_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07375_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07376_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07377_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07378_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07379_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07380_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07381_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07382_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07383_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07384_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07385_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07386_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07387_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07388_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07389_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07390_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07391_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07392_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07393_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07394_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07395_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07396_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07397_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07398_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07399_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07400_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07401_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07402_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07403_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07404_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07405_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07406_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07407_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07408_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07409_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07410_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07411_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07412_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07413_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07414_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07415_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07416_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07417_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07418_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07419_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07420_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07421_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07422_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07423_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07424_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07425_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07426_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07427_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07428_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07429_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07430_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07431_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07432_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07433_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07434_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07435_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07436_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07437_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07438_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07440_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07441_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07442_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07443_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07444_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07445_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07446_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07447_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07448_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07449_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07450_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07451_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07452_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07453_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07454_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07455_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07456_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07457_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07458_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07459_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07460_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07461_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07462_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07463_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07464_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07465_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07466_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07467_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07468_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07469_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07470_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07471_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07472_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07473_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07474_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07475_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07476_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07477_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07478_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07479_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07480_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07481_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07482_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07483_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07484_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07485_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07486_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07487_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07488_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07489_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07490_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07491_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07492_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07493_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07494_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07495_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07496_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07497_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07498_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07499_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07500_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07501_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07502_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07503_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07504_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07505_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07506_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07507_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07508_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07509_tl} {Mobile~phone~(Jersey)}
\tl_const:cn {c_phone_UK_ortsname_07510_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07511_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07512_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07513_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07514_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07515_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07516_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07517_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07518_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07519_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07520_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07521_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07522_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07523_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07525_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07526_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07527_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07528_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07529_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07530_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07531_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07532_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07533_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07534_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07535_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07536_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07537_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07538_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07539_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07540_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07541_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07542_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07543_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07544_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07545_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07546_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07547_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07548_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07549_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07550_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07551_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07552_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07553_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07554_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07555_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07556_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07557_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07558_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07559_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07560_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07561_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07562_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07563_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07564_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07565_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07566_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07567_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07568_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07569_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07570_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07572_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07573_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07574_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07575_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07576_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07577_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07578_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07579_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07580_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07581_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07582_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07583_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07584_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07585_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07586_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07587_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07588_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07589_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07590_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07591_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07592_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07593_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07594_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07595_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07596_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07597_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07598_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07599_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07600_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07602_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07623_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07624_tl} {Mobile~phone~(Isle~of~Man)}
\tl_const:cn {c_phone_UK_ortsname_07625_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07626_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07640_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07641_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07644_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07654_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07659_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07660_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07661_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07663_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07666_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07669_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07677_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07681_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07693_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07699_tl} {Radiopaging}
\tl_const:cn {c_phone_UK_ortsname_07700_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07701_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07702_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07703_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07704_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07705_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07706_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07707_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07708_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07709_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07710_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07711_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07712_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07713_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07714_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07715_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07716_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07717_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07718_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07719_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07720_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07721_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07722_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07723_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07724_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07725_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07726_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07727_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07728_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07729_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07730_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07731_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07732_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07733_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07734_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07735_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07736_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07737_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07738_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07739_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07740_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07741_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07742_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07743_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07744_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07745_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07746_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07747_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07748_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07749_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07750_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07751_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07752_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07753_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07754_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07755_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07756_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07757_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07758_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07759_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07760_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07761_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07762_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07763_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07764_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07765_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07766_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07767_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07768_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07769_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07770_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07771_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07772_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07773_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07774_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07775_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07776_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07777_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07778_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07779_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07780_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07781_tl} {Mobile~phone~(Guernsey)}
\tl_const:cn {c_phone_UK_ortsname_07782_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07783_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07784_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07785_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07786_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07787_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07788_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07789_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07790_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07791_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07792_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07793_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07794_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07795_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07796_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07797_tl} {Mobile~phone~(Jersey)}
\tl_const:cn {c_phone_UK_ortsname_07798_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07799_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07800_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07801_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07802_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07803_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07804_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07805_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07806_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07807_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07808_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07809_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07810_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07811_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07812_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07813_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07814_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07815_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07816_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07817_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07818_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07819_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07820_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07821_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07822_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07823_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07824_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07825_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07826_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07827_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07828_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07829_tl} {Mobile~phone~(Jersey)}
\tl_const:cn {c_phone_UK_ortsname_07830_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07831_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07832_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07833_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07834_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07835_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07836_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07837_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07838_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07839_tl} {Mobile~phone~(Guernsey)}
\tl_const:cn {c_phone_UK_ortsname_07840_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07841_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07842_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07843_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07844_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07845_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07846_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07847_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07848_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07849_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07850_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07851_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07852_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07853_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07854_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07855_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07856_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07857_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07858_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07859_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07860_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07861_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07862_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07863_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07864_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07865_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07866_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07867_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07868_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07869_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07870_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07871_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07872_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07873_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07874_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07875_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07876_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07877_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07878_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07879_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07880_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07881_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07882_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07883_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07884_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07885_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07886_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07887_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07888_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07889_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07890_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07891_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07892_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07893_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07894_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07895_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07896_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07897_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07898_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07899_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07900_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07901_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07902_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07903_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07904_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07905_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07906_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07907_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07908_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07909_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07910_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07911_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07912_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07913_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07914_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07915_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07916_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07917_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07918_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07919_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07920_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07921_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07922_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07923_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07924_tl} {Mobile~phone~(Isle~of~Man)}
\tl_const:cn {c_phone_UK_ortsname_07925_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07926_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07927_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07928_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07929_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07930_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07931_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07932_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07933_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07934_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07935_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07936_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07937_tl} {Mobile~phone~(Jersey)}
\tl_const:cn {c_phone_UK_ortsname_07938_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07939_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07940_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07941_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07942_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07943_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07944_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07945_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07946_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07947_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07948_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07949_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07950_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07951_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07952_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07953_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07954_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07955_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07956_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07957_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07958_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07959_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07960_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07961_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07962_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07963_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07964_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07965_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07966_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07967_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07968_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07969_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07970_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07971_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07972_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07973_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07974_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07975_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07976_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07977_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07978_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07979_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07980_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07981_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07982_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07983_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07984_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07985_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07986_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07987_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07988_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07989_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07990_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_07999_tl} {Mobile~phone}
\tl_const:cn {c_phone_UK_ortsname_0800_tl} {Freephone}
\tl_const:cn {c_phone_UK_ortsname_0808_tl} {Freephone}
\tl_const:cn {c_phone_UK_ortsname_0820_tl} {Internet~for~schools}
\tl_const:cn {c_phone_UK_ortsname_0843_tl} {Special~service~basic~rate}
\tl_const:cn {c_phone_UK_ortsname_0844_tl} {Special~service~basic~rate}
\tl_const:cn {c_phone_UK_ortsname_0845_tl} {Special~service~basic~rate}
\tl_const:cn {c_phone_UK_ortsname_0870_tl} {Special~service~higher~rate}
\tl_const:cn {c_phone_UK_ortsname_0871_tl} {Special~service~higher~rate}
\tl_const:cn {c_phone_UK_ortsname_0872_tl} {Special~service~higher~rate}
\tl_const:cn {c_phone_UK_ortsname_0897_tl} {Inserted~network~number}
\tl_const:cn {c_phone_UK_ortsname_0899_tl} {Inbound~routing~code}
\tl_const:cn {c_phone_UK_ortsname_0900_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0901_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0902_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0903_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0904_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0905_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0906_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0907_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0911_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0912_tl} {Special~service~premium~rate}
\tl_const:cn {c_phone_UK_ortsname_0913_tl} {Special~service~premium~rate}

\tl_const:Nn \c_phone_UK_landesadjektiv_tl {British}
\bool_const:Nn \c_phone_UK_erlaubt_durchwahl_bool {\c_false_bool}

\clist_new:N \c_phone_UK_vorwahlen_clist
\clist_concat:NNN \c_phone_UK_vorwahlen_clist \c_phone_UK_ortsvorwahlen_clist \c_phone_UK_sondervorwahlen_clist

\msg_new:nnn {phonenumbers} {UK/illegal home area code}
   {
      National~dialling~is~required~in~\tl_use:c {c_phone_UK_ortsname_ #1 _tl}.~#1~cannot~be~set~as~home~area~code~\msg_line_context:.
   }

\msg_new:nnn {phonenumbers} {UK/national dialling required}
   {
      British~subscriber~number~starting~with~0~or~1~requires~an~area~code~\msg_line_context:
   }

% Prüfe, ob eine Vorwahl als Heimatvorwahl zulässig ist.
% #1: Heimatvorwahl
\prg_new_protected_conditional:Npnn \phone_UK_heimatvorwahl_erlaubt:n #1 {T}
   {
      \clist_if_in:NnTF \c_phone_UK_ortsvorwahlen_clist {#1}
         {
            % In Großbritannien können nur nicht obligatorische Ortsvorwahlen Heimatvorwahl sein.
            \clist_if_in:NnTF \c_phone_UK_obligatorische_ortsvorwahlen_clist {#1}
               {
                  \msg_warning:onn {phonenumbers} {UK/illegal home area code} {#1}
                  \prg_return_false:
               }
               {
                  \prg_return_true:
               }
         }
         {
            \msg_warning:nnn {phonenumbers} {invalid home area code} {#1}
            \prg_return_false:
         }
   }

% #1: Vorwahl, #2: Soll die führende null ausgegeben werden?
\cs_new_protected:Npn \phone_UK_ziffernvorwahl_schreiben:nN #1#2
   {
      \int_compare:nNnTF { \str_count:n {#1} } = {6}
         {
            % sechsstellige Vorwahl: Gliederung vor der zweitletzten Ziffer
            \bool_if:NTF #2
               {
                  \int_compare:nNnTF {\l_phone_gruppierungsminimum_int} > {6}
                     {
                        \tl_put_right:Nn \l_phone_ausgabetext_tl {#1}
                     }
                     {
                        \tl_put_right:Nx \l_phone_ausgabetext_tl { \str_range:nnn {#1} {1} {4} }
                        \tl_put_right:Nn \l_phone_ausgabetext_tl {\,}
                        \tl_put_right:Nx \l_phone_ausgabetext_tl { \str_range:nnn {#1} {5} {6} }
                     }
               }
               {
                  \int_compare:nNnTF {\l_phone_gruppierungsminimum_int} > {5}
                     {
                        \tl_put_right:Nx \l_phone_ausgabetext_tl { \str_tail:n {#1} }
                     }
                     {
                        \tl_put_right:Nx \l_phone_ausgabetext_tl { \str_range:nnn {#1} {2} {4} }
                        \tl_put_right:Nn \l_phone_ausgabetext_tl {\,}
                        \tl_put_right:Nx \l_phone_ausgabetext_tl { \str_range:nnn {#1} {5} {6} }
                     }
               }
         }
         {
            % nicht sechsstellige Vorwahl
            \bool_if:NTF #2
               {
                  \tl_put_right:Nn \l_phone_ausgabetext_tl {#1}
               }
               {
                  \tl_put_right:Nx \l_phone_ausgabetext_tl { \str_tail:n {#1} }
               }
         }
   }

% #1: Vorwahl, #2: Folgt eine Rufnummer?
\cs_new_protected:Npn \phone_UK_vorwahl_schreiben:nn #1 #2
   {
      \bool_lazy_or:nnTF { \str_if_eq_p:Vn \l_phone_auslandsvorwahltyp_str {off} } { \str_if_eq_p:Vn \l_phone_heimatland_str {UK} }
         {
            \clist_if_in:NnT \c_phone_UK_sondervorwahlen_clist {#1}
               {
                  \str_if_eq:VnT \l_phone_vorwahldarstellung_str {place}
                     {
                        \str_set:Nn \l_phone_vorwahldarstellung_str {number}
                     }
               }

            \bool_lazy_and:nnF { \str_if_eq_p:Vn \l_phone_heimatland_str {UK} } { \str_if_eq_p:Vn \l_phone_heimatvorwahl_str {#1} }
               {
                  \str_case:Vn \l_phone_vorwahldarstellung_str
                     {
                        {number}
                           {
                              \bool_if:nTF {#2}
                                 {
                                    \str_if_eq:VnTF \l_phone_vorwahltrennung_str {space}
                                       {
                                          \phone_UK_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                       }
                                       {
                                          \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                       }

                                    \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                 }
                                 {
                                    \phone_UK_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                 }
                           }
                        {place}
                           {
                              \bool_if:nTF {#2}
                                 {
                                    \str_if_eq:VnF \l_phone_vorwahltrennung_str {space}
                                       {
                                          \tl_put_right:Nn \l_phone_ausgabetext_tl {(}
                                       }

                                    \tl_if_exist:cTF {c_phone_UK_ortsname_ #1 _tl}
                                       {
                                          \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_UK_ortsname_ #1 _tl}
                                       }
                                       {
                                          \phone_UK_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                       }

                                    \str_if_eq:VnF \l_phone_vorwahltrennung_str {space}
                                       {
                                          \tl_put_right:Nn \l_phone_ausgabetext_tl {)}
                                       }

                                    \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                 }
                                 {
                                    \tl_if_exist:cTF {c_phone_UK_ortsname_ #1 _tl}
                                       {
                                          \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_UK_ortsname_ #1 _tl}
                                       }
                                       {
                                          \phone_UK_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                       }
                                 }
                           }
                        {place-and-number}
                           {
                              \tl_if_exist:cT {c_phone_UK_ortsname_ #1 _tl}
                                 {
                                    \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_UK_ortsname_ #1 _tl}
                                    \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                 }

                              \str_if_eq:VnTF \l_phone_vorwahltrennung_str {space}
                                 {
                                    \phone_UK_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                 }
                                 {
                                    \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                 }

                              \bool_if:nT {#2}
                                 {
                                    \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                 }
                           }
                     }
               }
         }
         {
            \phone_ungruppierte_auslandsvorwahl_schreiben:n {44}

            \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl

            \str_if_eq:VnTF \l_phone_auslandsvorwahltrennung_str {space}
               {
                  \phone_UK_ziffernvorwahl_schreiben:nN {#1} \c_false_bool
               }
               {
                  \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_false_bool
               }

            \bool_if:nT {#2}
               {
                  \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
               }
         }

      % Linktext schreiben, falls eine Rufnummer folgt
      \bool_if:nT {#2}
         {
            \str_put_right:Nn \l_phone_linktext_str {+44}
            \str_put_right:Nx \l_phone_linktext_str { \str_tail:n {#1} }
         }
   }

\cs_generate_variant:Nn \phone_UK_vorwahl_schreiben:nn {Vx}

% #1: Vorwahl, #2: Teilnehmerrufnummer
\cs_new_protected:Npn \phone_UK_teilnehmerrufnummer_schreiben:Nn #1 #2
   {
      % Überprüfen der Nummernlänge
      \str_if_empty:NTF #1
         {
            % Festnetznummer ohne Vorwahl (kann zwischen 4 und 8 Ziffern haben)
            \phone_nummernlaenge_ueberpruefen:nnnn {#2} {4} {8} {landline}

            % Nummern, die mit 0 oder 1 beginnen, erfordern das Wählen der Vorwahl
            \str_case:xnT { \str_head:n {#2} }
               {
                  {0} { }
                  {1} { }
               }
               {
                  \msg_warning:nn {phonenumbers} {UK/national dialling required}
               }
         }
         {
            \clist_if_in:NVTF \c_phone_UK_ortsvorwahlen_clist #1
               {
                  % Festnetznummer, muss in der Regel 11 Ziffern umfassen
                  % Ausnahme: Bei den Vorwahlen 01XXX und 016977 sind auch 10 Ziffern möglich.
                  \bool_lazy_or:nnTF { \str_if_eq_p:Vn #1 {016977} } { \int_compare_p:nNn { \str_count:N #1 } = {5} }
                     {
                        \phone_nummernlaenge_ueberpruefen:onnn {#1#2} {10} {11} {landline}
                     }
                     {
                        \phone_nummernlaenge_ueberpruefen:onnn {#1#2} {11} {11} {landline}
                     }
               }
               {
                  % Mobilfunk-/Sondernummer
                  \str_if_eq:xnTF { \str_range:Nnn #1 {1} {4} } {0800}
                     {
                        % 0800er-Nummern haben 10 oder 11 Ziffern; Ausnahme: 0800 1111
                        \str_if_eq:nnTF {#2} {1111}
                           {
                              \bool_set_true:N \l_phone_teilnehmerrufnummer_gueltig_bool
                           }
                           {
                              \phone_nummernlaenge_ueberpruefen:onnn {#1#2} {10} {11} {freephone}
                           }
                     }
                     {
                        % alle anderen Sondernummern haben 11 Ziffern
                        \phone_nummernlaenge_ueberpruefen:onnn {#1#2} {11} {11} {non-geographic}
                     }
               }

            \bool_if:NTF \l_phone_teilnehmerrufnummer_gueltig_bool
               {
                  % Für gültige Nummern mit Vorwahl Linktext schreiben:
                  \str_put_right:Nn \l_phone_linktext_str {#2}
               }
               {
                  % Für ungültige Nummern mit Vorwahl Linktext löschen:
                  \str_clear:N \l_phone_linktext_str
               }
         }

      \bool_if:NTF \l_phone_teilnehmerrufnummer_gueltig_bool
         {
            \int_compare:nNnTF { \str_count:n {#2} } > {6}
               {
                  % Nummern mit mehr als 6 Ziffern werden in Vierergruppen gegliedert
                  \str_put_right:Nx \l_phone_ausgabetext_tl { \str_range:nnn {#2} {1} {-5} }
                  \tl_put_right:Nn \l_phone_ausgabetext_tl {\,}
                  \str_put_right:Nx \l_phone_ausgabetext_tl { \str_range:nnn {#2} {-4} {-1} }
               }
               {
                  \str_put_right:Nn \l_phone_ausgabetext_tl {#2}
               }
         }
         {
            \str_put_right:Nn \l_phone_ausgabetext_tl {#2}
         }
   }

\cs_generate_variant:Nn \phone_UK_teilnehmerrufnummer_schreiben:Nn {Nx,NV}

\cs_new_protected:Npn \phone_UK_nummer_schreiben:
   {
      \int_set:Nn \l_phone_nummernlaenge_int { \str_count:N \l_phone_bereinigte_nummer_str }

      \str_if_eq:xnTF { \str_head:N \l_phone_bereinigte_nummer_str } {0}
         {
            \bool_set_false:N \l_phone_vorwahl_gefunden_bool

            \int_step_inline:nnnn {6} {-1} {3}
               {
                  \bool_if:NF \l_phone_vorwahl_gefunden_bool
                     {
                        \int_compare:nT { \l_phone_nummernlaenge_int >= ##1 }
                           {
                              \str_set:Nx \l_phone_vorwahl_str { \str_range:Nnn \l_phone_bereinigte_nummer_str {1} {##1} }

                              \clist_if_in:NVT \c_phone_UK_vorwahlen_clist \l_phone_vorwahl_str
                                 {
                                    \bool_set_true:N \l_phone_vorwahl_gefunden_bool

                                    \phone_UK_vorwahl_schreiben:Vx \l_phone_vorwahl_str { \int_compare_p:nNn {##1} < {\l_phone_nummernlaenge_int} }

                                    \int_compare:nNnTF {##1} = {\l_phone_nummernlaenge_int}
                                       {
                                          \msg_warning:nn {phonenumbers} {missing subscriber number}
                                       }
                                       {
                                          \phone_UK_teilnehmerrufnummer_schreiben:Nx \l_phone_vorwahl_str { \str_range:Nnn \l_phone_bereinigte_nummer_str {##1 + 1} {-1} }
                                       }
                                 }
                           }
                     }
               }

            \bool_if:NF \l_phone_vorwahl_gefunden_bool
               {
                  \msg_warning:nn {phonenumbers} {invalid area code}
                  \tl_put_right:NV \l_phone_ausgabetext_tl \l_phone_bereinigte_nummer_str
               }
         }
         {
            \phone_UK_teilnehmerrufnummer_schreiben:NV \c_empty_tl \l_phone_bereinigte_nummer_str
         }
   }

\cs_new_protected:Npn \phone_UK_vorwahlliste_ausgeben:n #1
   {
      \begin{tabbing}
      \hspace {4em} \= \kill

      \bool_set_false:N \l_phone_zeilenumbruch_bool

      \clist_map_inline:cn {c_phone_UK_ #1 _clist}
         {
            \bool_if:NTF \l_phone_zeilenumbruch_bool
               {
                  \\
               }
               {
                  \bool_gset_true:N \l_phone_zeilenumbruch_bool
               }

            \phone_UK_ziffernvorwahl_schreiben:nN {##1} \c_true_bool
            \tl_use:N \l_phone_ausgabetext_tl
            \>
            \tl_if_exist:cT {c_phone_UK_ortsname_ ##1 _tl}
               {
                  \tl_use:c {c_phone_UK_ortsname_ ##1 _tl}
               }
         }
      \end{tabbing}
   }
